<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Jednoduchý a uživatelsky přívětivý Jabber/XMPP klient</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Licence:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Prohlédnout zdrojový kód online</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Smazat</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Změna hesla</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Stávající heslo:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nové heslo:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Nové heslo (opakovat):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Nová hesla se neshodují.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Stávající heslo je neplatné.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation>Pro změnu hesla je nutné být připojen.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Po změně hesla bude třeba zadat nové heslo na všech vašich ostatních zařízeních.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Změnit</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Zkopírovat zprávu</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Editovat zprávu</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>«Spoiler»</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stahnout</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Kopírovat stažitelnou URL</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished">Kopírovat stažitelnou URL</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation>Vytvořit zprávu</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Obrázek</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Dokument</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Další soubor</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Vybrat soubor</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Zaslat «spoiler» zprávu</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation>«Spoiler» tip</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Zapnout notifikace</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Vypnout notifikace</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Prohlédnout profil</translation>
    </message>
    <message>
        <source>Multimedia settings</source>
        <translation type="vanished">Nastavení multimédií</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Hledat výše</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Hledat níže</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="obsolete">Kopírovat stažitelnou URL</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Velmi nízká</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Nízká</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Vysoká</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Velmi vysoká</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Stálá kvalita</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Stálý datový tok</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Průměrný datový tok</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Dvouproudový</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Download failed.</source>
        <translation type="vanished">Stahování selhalo.</translation>
    </message>
    <message>
        <source>Could not save file: %1</source>
        <translation>Soubor nelze uložit: %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Chyba při stahování: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Lidé</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation>Příroda</translation>
    </message>
    <message>
        <source>Food</source>
        <translation>Jídlo</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation>Činnosti</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation>Cestování</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation>Předměty</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation>Symboly</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Vlajky</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation>Hledat emoji</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Pro zahájení konverzace vyberte chat</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Vybrat soubor</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Přesun o adresář výše</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Zavřít</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Odhlásit se</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Pozvat přátele</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Zvací odkaz zkopírován do schránky</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">Připojování…</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Odkaz se  otevře jakmile se připojíte.</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">Heslo nenalezeno. Prosím zadejte heslo.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Nebyl nalezen žádný platný přihlašovací kód QR.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>Přihlásit se</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Přihlásit se ke svému XMPP účtu</translation>
    </message>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Vaše Jabber-ID:</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Vaše diaspora*-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">uživatel@example.org</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">uživatel@diaspora.pod</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Vaše heslo:</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Připojování…</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Připojit</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Neplatný uživatel nebo heslo.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Nelze se připojit k serveru.
Prosím zkontrolujte své připojení k internetu.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Server nepodporuje zabezpečená připojení.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Hlášení o chybě při pokusu o zabezpečené připojení.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Neznámá adresa serveru. Zkontrolujte znovu vaše JID.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Nebylo možné se připojit k serveru.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Ověřovací protokol není kompatibilní se serverem.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Došlo k neznámé chybě; pro více informací zkontrolujte seznam logů.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Přihlaste se pomocí QR kódu</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Vyfotit</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Nahrát video</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Nahrát hlas</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Zaslat polohu</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Vybrat soubor</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Vybrat obrázek</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Vybrat video</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Vybrat audio soubor</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Vybrat dokument</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videa</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Audio soubory</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Nelze odeslat zprávu, neboť nejste připojeni.</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Zprávu nelze editovat, neboť nejste připojeni.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">«Spoiler»</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Zprávu se nepodařilo odeslat.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>Oprava zprávy se nezdařila.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Chyba</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished">Nastavení multimédií</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="unfinished">Nastavit</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="unfinished">Zachycení obrazu</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="unfinished">Audio nahrávání</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished">Video nahrávání</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished">Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="unfinished">Audio vstup</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished">Kontejner</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">Obrázek</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished">Kodek</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished">Rozlišení</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished">Kvalita</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished">Vzorkovací frekvence</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="unfinished">Snímková frekvence</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Připravený</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished">Zahajuji…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished">Nedostupný</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="unfinished">Nahrávám…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished">Pozastaven</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Nastavení multimédií</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="vanished">Nastavit</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="vanished">Zachycení obrazu</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="vanished">Audio nahrávání</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="vanished">Video nahrávání</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="vanished">Kamera</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="vanished">Audio vstup</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="vanished">Kontejner</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Obrázek</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="vanished">Kodek</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="vanished">Rozlišení</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="vanished">Kvalita</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="vanished">Vzorkovací frekvence</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="vanished">Snímková frekvence</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="vanished">Připravený</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="vanished">Zahajuji…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="vanished">Nedostupný</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="vanished">Nahrávám…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">Pozastaven</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation>Připravený</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Zahajuji…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Nedostupný</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Nahrávání… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>Pozastaveno %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation>Dostupný</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Dostupný k chatování</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Nepřítomný</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Nerušit</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Dlouhodobě nepřítomný</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Nepřipojený</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Neviditelný</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished">Neplatný uživatel nebo heslo.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="unfinished">Nelze se připojit k serveru.
Prosím zkontrolujte své připojení k internetu.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="unfinished">Server nepodporuje zabezpečená připojení.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="unfinished">Hlášení o chybě při pokusu o zabezpečené připojení.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Nebylo možné se připojit k serveru.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="unfinished">Ověřovací protokol není kompatibilní se serverem.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Naskenujte QR kód</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Není k dispozici žádná kamera.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>Váš fotoaparát je zaneprázdněn.
Zkuste zavřít jiné aplikace, které používají fotoaparát.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>Formát fotoaparátu &apos;% 1&apos; není podporován.</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">Připojování…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation>Změna hesla byla úspěšná.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Změna hesla se nezdařila: %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Smazat</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation>Přidat nový kontakt</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Zároveň odešle žádost o přístup k přítomnosti kontaktu.</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Jabber-ID:</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>uživatel@example.org</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Alias:</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Volitelná zpráva:</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Sdělit chatující proti-straně kdo jste.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation>Chyba: zkontrolujte prosím JID.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Dostupný</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Dostupný k chatování</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Nepřítomný</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Nerušit</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Dlouhodobě nepřítomný</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Nepřipojen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Chyba</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Nelze přidat kontakt, neboť nejste připojeni.</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Nelze smazat kontakt, neboť nejste připojeni.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>«Spoiler»</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Nepodařilo se kontakt přejmenovat, neboť nejste připojení.</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation>Připojování…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Kontakty</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Přidat nový kontakt</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Odpojen</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Prohledat kontakty</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation>Opravdu chcete smazat kontakt &lt;b&gt;%1&lt;/b&gt; z vašeho seznamu?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Smazat kontakt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Přejmenovat kontakt</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Editovat jméno:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation type="unfinished">Změna hesla</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished">Změní heslo k vašemu účtu. Bude třeba ho zadat na všech vašich zařízeních.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished">Nastavení multimédií</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Nastavení</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Změna hesla</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Změní heslo k vašemu účtu. Bude třeba ho zadat na všech vašich zařízeních.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="obsolete">Nastavení multimédií</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Nastavení</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Žádost o přihlášení</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Obdržena žádost o přihlášení od &lt;b&gt;%1&lt;/b&gt;. Pokud přijmete, daný účet bude mít přístup k informaci o vašem připojení.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Odmítnout</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Přijmout</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Soubor nelze odeslat, neboť nejste připojeni.</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished">Zprávu se nepodařilo odeslat.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Alias</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Datum narození</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Webová stránka</translation>
    </message>
</context>
</TS>
